@@ -243,6 +243,7 @@ const HoverFilterTag = GObject.registerClass({
         this.foreground_rgba = color;
     }
 
+    // eslint-disable-next-line camelcase
     set filtered_tag(value) {
         this._filteredTag = value;
         this.notify('filtered-tag');
@@ -253,10 +254,12 @@ const HoverFilterTag = GObject.registerClass({
         this._updateColor();
     }
 
+    // eslint-disable-next-line camelcase
     get filtered_tag() {
         return this._filteredTag;
     }
 
+    // eslint-disable-next-line camelcase
     set hover_opacity(value) {
         if (this._hoverOpacity == value)
             return;
@@ -267,6 +270,7 @@ const HoverFilterTag = GObject.registerClass({
             this._updateColor();
     }
 
+    // eslint-disable-next-line camelcase
     get hover_opacity() {
         return this._hoverOpacity;
     }
@@ -620,15 +624,14 @@ var ChatView = GObject.registerClass({
             if (!iter.is_end() || i < pending.length - 1)
                 this._view.buffer.insert(iter, '\n', -1);
         }
-
-        if (!this._channel)
-            return;
     }
 
+    // eslint-disable-next-line camelcase
     get max_nick_chars() {
         return this._maxNickChars;
     }
 
+    // eslint-disable-next-line camelcase
     get can_drop() {
         return this._channel != null;
     }
@@ -1307,8 +1310,8 @@ var ChatView = GObject.registerClass({
         if (this._room.type == Tp.HandleType.CONTACT &&
             status == Tp.ConnectionPresenceType.OFFLINE &&
             this._room.channel)
-            this._room.channel.ack_all_pending_messages_async(() => {
-                this._room.channel.close_async(null);
+            this._room.channel.ack_all_pending_messages_async(channel => {
+                channel.close_async(null);
             });
 
         let nickTagName = this._getNickTagName(baseNick);
