@@ -99,8 +99,9 @@ var NetworksManager = class {
 
     getNetworkMatchTerms(id) {
         let network = this._lookupNetwork(id);
-        let terms = [network.name, network.id, ...network.servers];
-        return terms.map(String.toLowerCase);
+        let servers = network.servers.map(s => s.address);
+        let terms = [network.name, network.id, ...servers];
+        return terms.map(t => t.toLowerCase());
     }
 
     findByServer(server) {
